PoliciesClient

Struct PoliciesClient 

pub struct PoliciesClient(pub(crate) PolicyClient);
Client for policy domain operations.

Tuple Fields

0: PolicyClient

Implementations

Source

impl PoliciesClient

pub fn filter_by_type( &self, policies: Vec<PolicyView>, organizations: Vec<ProfileOrganization>, policy_type: PolicyType, ) -> Vec<PolicyView>

Filter policies of the given type for the current user.

Returns the subset of policies that should be enforced against the user, based on their organization memberships and roles.